@@ -1,4 +1,5 @@
 from django.shortcuts import redirect
+from django.http import HttpResponseRedirect
 from django.utils.cache import add_never_cache_headers
 from django.core.signing import BadSignature
 from django.core.signing import SignatureExpired
@@ -23,26 +24,26 @@ class BaseTempusMiddleware(object):
         response = redirect(unicode(redirect_url))
         try:
             token_data = tempus_loads(token, max_age=self.max_age)
-            tempus = getattr(request, 'tempus')
+            tempus = getattr(request, 'tempus', None)
             if tempus:
                 current_tempus = tempus.copy()
                 request.tempus = current_tempus.update(token_data)
             else:
                 request.tempus = token_data
         except SignatureExpired:
-            expired_func = getattr(self, 'expired_func')
+            expired_func = getattr(self, 'expired_func', None)
             if expired_func:
-                expired_func(request)
+                value = expired_func(request)
+                if isinstance(value, HttpResponseRedirect):
+                    return value
         except BadSignature:
             return response
         else:
-            self.success_func(request)
+            success_func = getattr(self, 'success_func', None)
+            if success_func:
+                value = success_func(request)
+                if isinstance(value, HttpResponseRedirect):
+                    return value
 
             add_never_cache_headers(response)
             return response
-
-    def success_func(self, request):
-        pass
-
-    def expired_func(self, request):
-        pass
